package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallIndustry;
import com.ruoyi.mall.domain.Vo.MallIndustryVo;

/**
 * 行业Service接口
 * 
 * @author LCL
 * @date 2023-10-20
 */
public interface IMallIndustryService 
{
    /**
     * 查询行业
     * 
     * @param industryId 行业主键
     * @return 行业
     */
    public MallIndustry selectMallIndustryByIndustryId(Long industryId);

    /**
     * 查询行业列表
     * 
     * @param mallIndustry 行业
     * @return 行业集合
     */
    public List<MallIndustry> selectMallIndustryList(MallIndustry mallIndustry);

    /**
     * 查询行业列表 分组行业分类 xcx Api
     *
     * @param mallIndustry 行业
     * @return 行业集合
     */
    public List<MallIndustryVo> selectMallIndustryListForxcx(MallIndustry mallIndustry);

    /**
     * 新增行业
     * 
     * @param mallIndustry 行业
     * @return 结果
     */
    public int insertMallIndustry(MallIndustry mallIndustry);

    /**
     * 修改行业
     * 
     * @param mallIndustry 行业
     * @return 结果
     */
    public int updateMallIndustry(MallIndustry mallIndustry);

    /**
     * 批量删除行业
     * 
     * @param industryIds 需要删除的行业主键集合
     * @return 结果
     */
    public int deleteMallIndustryByIndustryIds(Long[] industryIds);

    /**
     * 删除行业信息
     * 
     * @param industryId 行业主键
     * @return 结果
     */
    public int deleteMallIndustryByIndustryId(Long industryId);
}
